@@ -1,8 +1,6 @@
-from decimal import Decimal, getcontext
 from itertools import takewhile, repeat
 from functools import wraps
 from uuid import uuid4
-from math import floor
 from decimal import *
 import numpy as np
 import datetime
@@ -1173,104 +1171,84 @@ class Handler(object):
         if verbose:
             sys.stdout.write('Lines in file: {}\n'.format(str(n_lines)))
 
-        if read_random:
-            if 0.0 < percent_random <= 100.0:
-                if verbose:
-                    sys.stdout.write('Randomizing index ... \n')
-                n_rand_lines = int((float(percent_random) / 100.0) * float(n_lines))
-                index_list = sorted([0] + Sublist(range(1, n_lines)).random_selection(num=n_rand_lines,
-                                                                                      systematic=systematic))
-        if verbose:
-            sys.stdout.write('Reading file : ')
-
         counter = 0
-        perc_ = 0
+        err_counter = 0
+        colnames = None
         with open(self.filename, 'r') as f:
-            if line_limit:
-                if len(index_list) > 0:
-                    if 0 < len(index_list) <= line_limit:
-                        pass
-                    elif len(index_list) > line_limit:
-                        index_list = index_list[:(line_limit + 1)]
 
-                    for i, line in enumerate(f):
-                        if counter > line_limit:
-                            break
-                        if i == index_list[counter]:
+            if not read_random:
+                if line_limit is None:
+                    for line in f:
+                        if counter == 0:
+                            colnames = list(elem.strip() for elem in line.split(','))
+                        elif len(line.split(',')) != len(colnames):
+                            err_counter += 1
+                        else:
                             lines.append(list(elem.strip() for elem in line.split(',')))
-                            counter += 1
-
-                            if counter > int((float(perc_) / 100.0) * float(len(index_list))):
-                                if verbose:
-                                    sys.stdout.write('{}..'.format(str(perc_)))
-                                perc_ += 10
-                    if verbose:
-                        sys.stdout.write('!\n')
+                        counter += 1
 
                 else:
                     for line in f:
-                        if counter > line_limit:
+                        if counter == 0:
+                            colnames = list(elem.strip() for elem in line.split(','))
+                        elif len(line.split(',')) != len(colnames):
+                            err_counter += 1
+                        elif counter <= line_limit:
+                            lines.append(list(elem.strip() for elem in line.split(',')))
+                        else:
                             break
-                        lines.append(list(elem.strip() for elem in line.split(',')))
                         counter += 1
 
-                        if counter > int((float(perc_) / 100.0) * float(line_limit)):
-                            if verbose:
-                                sys.stdout.write('{}..'.format(str(perc_)))
-                            perc_ += 10
-                    if verbose:
-                        sys.stdout.write('!\n')
-
             else:
-                if len(index_list) > 0:
+                if percent_random > 100.0:
+                    percent_random = 100.0
+                elif percent_random < 0.0:
+                    percent_random = 0.0
+                n_rand_lines = int((float(percent_random) / 100.0) * float(n_lines))
 
-                    for i, line in enumerate(f):
-                        if counter >= len(index_list):
-                            break
+                if n_rand_lines == 0:
+                    lines = []
+                else:
+                    if n_rand_lines == n_lines:
+                        index_list = list(range(0, n_lines))
+                    else:
+                        index_list = sorted([0] + Sublist(range(1, n_lines)).random_selection(num=n_rand_lines,
+                                                                                              systematic=systematic))
+                    if line_limit is not None:
+                        if n_rand_lines > line_limit:
+                            index_list = index_list[:line_limit]
 
-                        if index_list[counter] == i:
+                    for il, line in enumerate(f):
+                        if counter == 0:
+                            colnames = list(elem.strip() for elem in line.split(','))
+                            counter += 1
+                        elif len(line.split(',')) != len(colnames):
+                            err_counter += 1
+                        elif il == index_list[counter]:
                             lines.append(list(elem.strip() for elem in line.split(',')))
                             counter += 1
 
-                            if counter > int((float(perc_) / 100.0) * float(len(index_list))):
-                                if verbose:
-                                    sys.stdout.write('{}..'.format(str(perc_)))
-                                perc_ += 10
-                    if verbose:
-                        sys.stdout.write('!\n')
-
-                else:
-                    for line in f:
-                        lines.append(list(elem.strip() for elem in line.split(',')))
-                        counter += 1
-
-                        if counter > int((float(perc_) / 100.0) * float(n_lines)):
-                            if verbose:
-                                sys.stdout.write('{}..'.format(str(perc_)))
-                            perc_ += 10
-                    if verbose:
-                        sys.stdout.write('!\n')
-
-        # convert col names to list of strings
-        names = list(elem.strip() for elem in lines[0])
+        if verbose:
+            Opt.cprint('Encountered {} errors in reading file: {}'.format(str(err_counter),
+                                                                          self.basename))
 
         if len(lines) > 0:
             # convert to list
             if return_dicts:
                 if verbose:
                     sys.stdout.write('Converting to Dictionaries...\n')
-                return list(dict(zip(names, list(self.string_to_type(elem) for elem in feat)))
+                return list(dict(zip(colnames, list(self.string_to_type(elem) for elem in feat)))
                             for feat in lines[1:])
             else:
                 return {
                     'feature': list(list(self.string_to_type(elem) for elem in feat)
                                     for feat in lines[1:]),
-                    'name': names,
+                    'name': colnames,
                 }
         else:
             return {
-                'feature': list(),
-                'name': list(),
+                'feature': [],
+                'name': [],
             }
 
     @staticmethod
