@@ -1470,14 +1470,14 @@ class Raster(object):
 
         return list(out_geom_extract[internal_id] for internal_id in geom_id_order)
 
-    def clip(self,
-             cutline_file=None,
-             cutline_blend=0,
-             outfile=None,
-             return_vrt=False,
-             return_vrt_dict=False,
-             cutline_as_mask=True,
-             **creation_options):
+    def clip_by_geom(self,
+                     cutline_file=None,
+                     cutline_blend=0,
+                     outfile=None,
+                     return_vrt=False,
+                     return_vrt_dict=False,
+                     cutline_as_mask=True,
+                     **creation_options):
         """
         Method to clip a raster to a given geometry/vector
         This method only supports clipping to the first layer in the datasource
@@ -1534,6 +1534,74 @@ class Raster(object):
                 vrt_ds = None
                 return Raster(outfile)
 
+    def clip_by_extent(self,
+                       xmin,
+                       ymin,
+                       xmax,
+                       ymax,
+                       outfile=None,
+                       verbose=False,
+                       **kwargs):
+        """
+        Method to clip a raster by its CRS extent - xmin, ymin, xmax, ymax
+        :param xmin: x coordinate of lower left corner
+        :param ymin: y coordinate of lower left corner
+        :param xmax: x coordinate of upper right corner
+        :param ymax y coordinate of upper right corner
+        :param outfile: output file name (geotiff). If 'None' then the output will be written to memory
+                        and this method will return a GDAL datasource object
+        :param verbose: If some of the steps should be displayed
+        :param kwargs: Keyword arguments (ignored if outfile is None):
+                            examples: compress='lzw', bigtiff='yes'
+        """
+
+        if not self.init:
+            self.initialize()
+
+        pxmin, pxmax, pymin, pymax = self.get_pixel_bounds(bound_coords=(xmin, xmax, ymin, ymax),
+                                                           coords_type='crs')
+
+        ncols = pxmax - pxmin + 1
+        nrows = pymax - pymin + 1
+
+        if verbose:
+            Opt.cprint('pxmin {}, pymin {}, pxmax {}, pymax {}, ncols {}, nrows {}'.format(str(pxmin),
+                                                                                           str(pymin),
+                                                                                           str(pymax),
+                                                                                           str(pymax),
+                                                                                           str(ncols),
+                                                                                           str(nrows)))
+
+        tile_arr = self.get_tile(block_coords=(pxmin, pymin, ncols, nrows))
+        transform = (xmin,
+                     self.transform[1],
+                     self.transform[2],
+                     ymax,
+                     self.transform[4],
+                     self.transform[5])
+
+        outras = Raster(outfile,
+                        array=tile_arr,
+                        bnames=self.bnames,
+                        dtype=self.dtype,
+                        shape=tile_arr.shape,
+                        transform=transform,
+                        crs_string=self.crs_string,
+                        nodatavalue=self.nodatavalue)
+
+        if verbose:
+            Opt.cprint(outras)
+
+        if outfile is None:
+            return outras.write_to_file(driver='MEM')
+
+        else:
+            outras.write_to_file(**kwargs)
+
+            if verbose:
+                Opt.cprint('Written: {}'.format(outfile))
+            return
+
     def reproject(self,
                   outfile=None,
                   out_epsg=None,
